Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code | Sign in
(912)

Unified Diff: src/nix-vector-routing/model/ipv4-nix-vector-routing.h

Issue 319230044: Final updates to correct doxygen warnings for nix-vector-routing (Closed)
Patch Set: Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Please Sign in to add in-line comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/nix-vector-routing/examples/nms-p2p-nix.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/nix-vector-routing/model/ipv4-nix-vector-routing.h
===================================================================
--- a/src/nix-vector-routing/model/ipv4-nix-vector-routing.h
+++ b/src/nix-vector-routing/model/ipv4-nix-vector-routing.h
@@ -58,7 +58,7 @@
/**
* @brief The Interface ID of the Global Router interface.
*
- * @see Object::GetObject ()
+ * @return type ID
*/
static TypeId GetTypeId (void);
/**
@@ -83,63 +83,74 @@
private:
- /* flushes the cache which stores nix-vector based on
+ /** flushes the cache which stores nix-vector based on
* destination IP */
void FlushNixCache (void) const;
- /* flushes the cache which stores the Ipv4 route
+ /** flushes the cache which stores the Ipv4 route
* based on the destination IP */
void FlushIpv4RouteCache (void) const;
- /* upon a run-time topology change caches are
+ /** upon a run-time topology change caches are
* flushed and the total number of neighbors is
* reset to zero */
void ResetTotalNeighbors (void);
- /* takes in the source node and dest IP and calls GetNodeByIp,
- * BFS, accounting for any output interface specified, and finally
- * BuildNixVector to return the built nix-vector */
- Ptr<NixVector> GetNixVector (Ptr<Node>, Ipv4Address, Ptr<NetDevice>);
+ /** takes in the source node and dest IP and calls GetNodeByIp,
+ * BFS, accounting for any output interface specified, and finally
+ * BuildNixVector to return the built nix-vector
+ *
+ * \param source is the source node
+ * \param dest is the destination address
+ * \param oif is the net device
+ * \return Ptr<NixVector>
+ */
+ Ptr<NixVector> GetNixVector (Ptr<Node> source, Ipv4Address dest, Ptr<NetDevice> oif);
- /* checks the cache based on dest IP for the nix-vector */
+ /** checks the cache based on dest IP for the nix-vector */
Ptr<NixVector> GetNixVectorInCache (Ipv4Address);
- /* checks the cache based on dest IP for the Ipv4Route */
+ /** checks the cache based on dest IP for the Ipv4Route */
Ptr<Ipv4Route> GetIpv4RouteInCache (Ipv4Address);
- /* given a net-device returns all the adjacent net-devices,
+ /** given a net-device returns all the adjacent net-devices,
* essentially getting the neighbors on that channel */
void GetAdjacentNetDevices (Ptr<NetDevice>, Ptr<Channel>, NetDeviceContainer &);
- /* iterates through the node list and finds the one
+ /** iterates through the node list and finds the one
* corresponding to the given Ipv4Address */
Ptr<Node> GetNodeByIp (Ipv4Address);
- /* Recurses the parent vector, created by BFS and actually builds the nixvector */
+ /** Recurses the parent vector, created by BFS and actually builds the nixvector */
bool BuildNixVector (const std::vector< Ptr<Node> > & parentVector, uint32_t source, uint32_t dest, Ptr<NixVector> nixVector);
- /* special variation of BuildNixVector for when a node is sending to itself */
+ /** special variation of BuildNixVector for when a node is sending to itself */
bool BuildNixVectorLocal (Ptr<NixVector> nixVector);
- /* simple iterates through the nodes net-devices and determines
+ /** simple iterates through the nodes net-devices and determines
* how many neighbors it has */
uint32_t FindTotalNeighbors (void);
- /* determine if the netdevice is bridged */
+ /** determine if the netdevice is bridged */
Ptr<BridgeNetDevice> NetDeviceIsBridged (Ptr<NetDevice> nd) const;
- /* Nix index is with respect to the neighbors. The net-device index must be
- * derived from this */
+ /** Nix index is with respect to the neighbors. The net-device index must be
+ * derived from this
+ *
+ * \param nodeIndex
+ * \param gatewayIp
+ * \returns net device
+ */
uint32_t FindNetDeviceForNixIndex (uint32_t nodeIndex, Ipv4Address & gatewayIp);
/* Breadth first search algorithm
* Param1: total number of nodes
* Param2: Source Node
* Param3: Dest Node
* Param4: (returned) Parent vector for retracing routes
* Param5: specific output interface to use from source node, if not null
* Returns: false if dest not found, true o.w.
*/
bool BFS (uint32_t numberOfNodes,
Ptr<Node> source,
@@ -149,7 +160,7 @@
void DoDispose (void);
- /* From Ipv4RoutingProtocol */
+ /** From Ipv4RoutingProtocol */
virtual Ptr<Ipv4Route> RouteOutput (Ptr<Packet> p, const Ipv4Header &header, Ptr<NetDevice> oif, Socket::SocketErrno &sockerr);
virtual bool RouteInput (Ptr<const Packet> p, const Ipv4Header &header, Ptr<const NetDevice> idev,
UnicastForwardCallback ucb, MulticastForwardCallback mcb,
@@ -161,27 +172,27 @@
virtual void SetIpv4 (Ptr<Ipv4> ipv4);
virtual void PrintRoutingTable (Ptr<OutputStreamWrapper> stream, Time::Unit unit = Time::S) const;
- /*
+ /**
* Flushes routing caches if required.
*/
void CheckCacheStateAndFlush (void) const;
- /*
+ /**
* Flag to mark when caches are dirty and need to be flushed.
* Used for lazy cleanup of caches when there are many topology changes.
*/
static bool g_isCacheDirty;
- /* Cache stores nix-vectors based on destination ip */
+ /** Cache stores nix-vectors based on destination ip */
mutable NixMap_t m_nixCache;
- /* Cache stores Ipv4Routes based on destination ip */
+ /** Cache stores Ipv4Routes based on destination ip */
mutable Ipv4RouteMap_t m_ipv4RouteCache;
- Ptr<Ipv4> m_ipv4;
- Ptr<Node> m_node;
+ Ptr<Ipv4> m_ipv4; ///< IPv4
+ Ptr<Node> m_node; ///< node
- /* Total neighbors used for nix-vector to determine
+ /** Total neighbors used for nix-vector to determine
* number of bits */
uint32_t m_totalNeighbors;
};
@@ -83,63 +83,74 @@
uint32_t FindNetDeviceForNixIndex (uint32_t nodeIndex, Ipv4Address & gatewayIp);
- /* Breadth first search algorithm
- * Param1: total number of nodes
- * Param2: Source Node
- * Param3: Dest Node
- * Param4: (returned) Parent vector for retracing routes
- * Param5: specific output interface to use from source node, if not null
- * Returns: false if dest not found, true o.w.
+ /** Breadth first search algorithm
+ * \param numberOfNodes total number of nodes
+ * \param source Source Node
+ * \param dest Dest Node
+ * \param parentVector (returned) Parent vector for retracing routes
+ * \param oif specific output interface to use from source node, if not null
+ * \returns false if dest not found, true o.w.
*/
bool BFS (uint32_t numberOfNodes,
« no previous file with comments | « src/nix-vector-routing/examples/nms-p2p-nix.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
RSS Feeds Recent Issues | This issue
This is Rietveld f62528b